glass_mt library

Liquid Glass + Glassmorphism for Flutter

Classes

FakeGlass
A widget that aims to provide a similar look to LiquidGlass, but without the expensive shader.
GlassGlow
Represents a layer that can paint a glowing effect below its child.
GlassGlowLayer
Represents a layer that can paint a glowing effect below its child.
GlassmorphicAppBar
GlassmorphicBottomBar
GlassmorphicCard
GlassmorphicContainer
GlassmorphicDialog
GlassmorphicListTile
GlassmorphicTextField
GlassmorphicTheme
GlassmorphicThemeData
GlassShadow
Paints BoxShadows for a LiquidShape using canvas primitives
LgrLogs
Logging utilities for the Liquid Glass Renderer package.
LiquidGlass
A liquid glass shape.
LiquidGlassBlendGroup
A widget that groups multiple liquid glass shapes for blending.
LiquidGlassLayer
Represents a layer of multiple LiquidGlass shapes or LiquidGlassBlendGroups that have shared LiquidGlassSettings and will be rendered together.
LiquidGlassSettings
Represents the settings for a liquid glass effect.
LiquidOval
Represents an ellipse shape that can be used by a LiquidGlass widget.
LiquidRoundedRectangle
Represents a rounded rectangle shape that can be used by a LiquidGlass widget.
LiquidRoundedSuperellipse
Represents a squircle shape that can be used by a LiquidGlass widget.
LiquidShape
Represents a shape that can be used by a LiquidGlass widget.
LiquidStretch
A widget that provides a squash and stretch effect to its child based on user interaction.
RawLiquidStretch
Use this widget to apply a custom stretch effect in pixels to its child.

Enums

GestureMode
Controls which gesture handling mechanism is used to detect interactions.

Extensions

OffsetResistanceExtension on Offset
Provides withResistance method to apply drag resistance to an Offset.

Properties

debugPaintLiquidGlassGeometry bool
Whether to paint the liquid glass geometry texture for debugging purposes.
getter/setter pair